summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-07 10:59:16 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-07 10:59:16 -0600
commit54e8e7815a7a14273cfc446d540b00298a97a2dc (patch)
tree357a1e87cda8dc9961b01810bf6b00513dcb4e06
parent5075b3a008195981bf4bea3e3e54df524883f06d (diff)
downloadpiklab-54e8e781.tar.gz
piklab-54e8e781.zip
Rename KAbout to avoid conflicts with KDE4
-rw-r--r--src/common/nokde/nokde_kaboutdata.cpp30
-rw-r--r--src/common/nokde/nokde_kaboutdata.h38
-rw-r--r--src/common/nokde/nokde_kcmdlineargs.cpp4
3 files changed, 36 insertions, 36 deletions
diff --git a/src/common/nokde/nokde_kaboutdata.cpp b/src/common/nokde/nokde_kaboutdata.cpp
index fe8ab22..8b0a4fe 100644
--- a/src/common/nokde/nokde_kaboutdata.cpp
+++ b/src/common/nokde/nokde_kaboutdata.cpp
@@ -29,13 +29,13 @@
#include <tqstringlist.h>
TQString
-KAboutPerson::name() const
+TDEAboutPerson::name() const
{
return TQString::fromUtf8(mName);
}
TQString
-KAboutPerson::task() const
+TDEAboutPerson::task() const
{
if (mTask && *mTask)
return i18n(mTask);
@@ -44,32 +44,32 @@ KAboutPerson::task() const
}
TQString
-KAboutPerson::emailAddress() const
+TDEAboutPerson::emailAddress() const
{
return TQString::fromUtf8(mEmailAddress);
}
TQString
-KAboutPerson::webAddress() const
+TDEAboutPerson::webAddress() const
{
return TQString::fromUtf8(mWebAddress);
}
-KAboutTranslator::KAboutTranslator(const TQString & name,
+TDEAboutTranslator::TDEAboutTranslator(const TQString & name,
const TQString & emailAddress)
{
mName=name;
mEmail=emailAddress;
}
-TQString KAboutTranslator::name() const
+TQString TDEAboutTranslator::name() const
{
return mName;
}
-TQString KAboutTranslator::emailAddress() const
+TQString TDEAboutTranslator::emailAddress() const
{
return mEmail;
}
@@ -138,14 +138,14 @@ void
TDEAboutData::addAuthor( const char *name, const char *task,
const char *emailAddress, const char *webAddress )
{
- mAuthorList.append(KAboutPerson(name,task,emailAddress,webAddress));
+ mAuthorList.append(TDEAboutPerson(name,task,emailAddress,webAddress));
}
void
TDEAboutData::addCredit( const char *name, const char *task,
const char *emailAddress, const char *webAddress )
{
- mCreditList.append(KAboutPerson(name,task,emailAddress,webAddress));
+ mCreditList.append(TDEAboutPerson(name,task,emailAddress,webAddress));
}
void
@@ -295,22 +295,22 @@ TDEAboutData::bugAddress() const
return TQString::fromLatin1(mBugEmailAddress);
}
-const TQValueList<KAboutPerson>
+const TQValueList<TDEAboutPerson>
TDEAboutData::authors() const
{
return mAuthorList;
}
-const TQValueList<KAboutPerson>
+const TQValueList<TDEAboutPerson>
TDEAboutData::credits() const
{
return mCreditList;
}
-const TQValueList<KAboutTranslator>
+const TQValueList<TDEAboutTranslator>
TDEAboutData::translators() const
{
- TQValueList<KAboutTranslator> personList;
+ TQValueList<TDEAboutTranslator> personList;
if(d->translatorName == 0)
return personList;
@@ -359,9 +359,9 @@ TDEAboutData::translators() const
TQString name=*nit;
#if [[[TQT_VERSION IS DEPRECATED]]] < 0x040000
- personList.append(KAboutTranslator(name.stripWhiteSpace(), email.stripWhiteSpace()));
+ personList.append(TDEAboutTranslator(name.stripWhiteSpace(), email.stripWhiteSpace()));
#else
- personList.append(KAboutTranslator(name.trimmed(), email.trimmed()));
+ personList.append(TDEAboutTranslator(name.trimmed(), email.trimmed()));
#endif
}
diff --git a/src/common/nokde/nokde_kcmdlineargs.cpp b/src/common/nokde/nokde_kcmdlineargs.cpp
index 481f0b6..15fc238 100644
--- a/src/common/nokde/nokde_kcmdlineargs.cpp
+++ b/src/common/nokde/nokde_kcmdlineargs.cpp
@@ -632,10 +632,10 @@ TDECmdLineArgs::parseAllArgs()
} else if ( ::qstrcmp( option, "author") == 0 ) {
enable_i18n();
if ( about ) {
- const TQValueList<KAboutPerson> authors = about->authors();
+ const TQValueList<TDEAboutPerson> authors = about->authors();
if ( !authors.isEmpty() ) {
TQString authorlist;
- for (TQValueList<KAboutPerson>::ConstIterator it = authors.begin(); it != authors.end(); ++it ) {
+ for (TQValueList<TDEAboutPerson>::ConstIterator it = authors.begin(); it != authors.end(); ++it ) {
TQString email;
if ( !(*it).emailAddress().isEmpty() )
email = " <" + (*it).emailAddress() + ">";
diff --git a/src/common/nokde/nokde_kaboutdata.h b/src/common/nokde/nokde_kaboutdata.h
index 731a29f..93a7768 100644
--- a/src/common/nokde/nokde_kaboutdata.h
+++ b/src/common/nokde/nokde_kaboutdata.h
@@ -37,7 +37,7 @@
#ifndef _KABOUTDATA_H_
#define _KABOUTDATA_H_
-class KAboutPersonPrivate;
+class TDEAboutPersonPrivate;
class TDEAboutDataPrivate;
/**
@@ -59,7 +59,7 @@ class TDEAboutDataPrivate;
* "joe.user@host.org", 0);
* TDECmdLineArgs::init(argc, argv, &about);
*/
-class TDECORE_EXPORT KAboutPerson
+class TDECORE_EXPORT TDEAboutPerson
{
public:
/**
@@ -75,7 +75,7 @@ public:
*
* @param webAddress Home page of the person.
*/
- KAboutPerson( const char *name, const char *task,
+ TDEAboutPerson( const char *name, const char *task,
const char *emailAddress, const char *webAddress )
{
mName = name;
@@ -87,7 +87,7 @@ public:
* @internal
* Don't use. Required by TQValueList
*/
- KAboutPerson() {}
+ TDEAboutPerson() {}
/**
* The person's name
@@ -123,10 +123,10 @@ private:
const char *mEmailAddress;
const char *mWebAddress;
- KAboutPersonPrivate *d;
+ TDEAboutPersonPrivate *d;
};
-class KAboutTranslatorPrivate;
+class TDEAboutTranslatorPrivate;
/**
* This structure is used to store information about a translator.
* It can store the translator's name and an email address.
@@ -134,12 +134,12 @@ class KAboutTranslatorPrivate;
* but it can be used elsewhere as well.
* Normally you should at least define the translator's name.
*
* It's not possible to use KAboutPerson for this, because
* KAboutPerson stores internally only const char* pointers, but the
* translator information is generated dynamically from the translation
* of a dummy string.
*/
-class TDECORE_EXPORT KAboutTranslator
+class TDECORE_EXPORT TDEAboutTranslator
{
public:
/**
@@ -149,7 +149,7 @@ public:
*
* @param emailAddress The email address of the person.
*/
- KAboutTranslator(const TQString & name=TQString(),
+ TDEAboutTranslator(const TQString & name=TQString(),
const TQString & emailAddress=TQString());
/**
@@ -169,7 +169,7 @@ public:
private:
TQString mName;
TQString mEmail;
- KAboutTranslatorPrivate* d;
+ TDEAboutTranslatorPrivate* d;
};
@@ -177,10 +177,10 @@ private:
* This class is used to store information about a program. It can store
* such values as version number, program name, home page, email address
* for bug reporting, multiple authors and contributors
- * (using KAboutPerson), license and copyright information.
+ * (using TDEAboutPerson), license and copyright information.
*
* Currently, the values set here are shown by the "About" box
* (see KAboutDialog), used by the bug report dialog (see KBugReport),
* and by the help shown on command line (see TDECmdLineArgs).
*
* @short Holds information needed by the "About" box and other
@@ -326,7 +326,7 @@ class TDECORE_EXPORT TDEAboutData
*
* @param name the name of the translator
* @param emailAddress the email address of the translator
- * @see KAboutTranslator
+ * @see TDEAboutTranslator
*/
void setTranslator(const char* name, const char* emailAddress);
@@ -509,19 +509,19 @@ class TDECORE_EXPORT TDEAboutData
* Returns a list of authors.
* @return author information (list of persons).
*/
- const TQValueList<KAboutPerson> authors() const;
+ const TQValueList<TDEAboutPerson> authors() const;
/**
* Returns a list of persons who contributed.
* @return credit information (list of persons).
*/
- const TQValueList<KAboutPerson> credits() const;
+ const TQValueList<TDEAboutPerson> credits() const;
/**
* Returns a list of translators.
* @return translators information (list of persons)
*/
- const TQValueList<KAboutTranslator> translators() const;
+ const TQValueList<TDEAboutTranslator> translators() const;
/**
* Returns a message about the translation team.
@@ -560,8 +560,8 @@ class TDECORE_EXPORT TDEAboutData
const char *mOtherText;
const char *mHomepageAddress;
const char *mBugEmailAddress;
- TQValueList<KAboutPerson> mAuthorList;
- TQValueList<KAboutPerson> mCreditList;
+ TQValueList<TDEAboutPerson> mAuthorList;
+ TQValueList<TDEAboutPerson> mCreditList;
const char *mLicenseText;
TDEAboutDataPrivate *d;
@@ -134,12 +134,12 @@ class KAboutTranslatorPrivate;
* Normally you should at least define the translator's name.
*
- * It's not possible to use KAboutPerson for this, because
- * KAboutPerson stores internally only const char* pointers, but the
+ * It's not possible to use TDEAboutPerson for this, because
+ * TDEAboutPerson stores internally only const char* pointers, but the
* translator information is generated dynamically from the translation
* of a dummy string.
@@ -177,10 +177,10 @@ private:
*
* Currently, the values set here are shown by the "About" box
- * (see KAboutDialog), used by the bug report dialog (see KBugReport),
+ * (see TDEAboutDialog), used by the bug report dialog (see KBugReport),
* and by the help shown on command line (see TDECmdLineArgs).
*